==> qt5-xmlpatterns-debuginfo-5.9.2-1.tar.xz: usr/src/debug/qt5-xmlpatterns-5.9.2-1/examples/xmlpatterns/filetree/.rcc/qrc_queries.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-xmlpatterns/qt5-xmlpatterns-5.9.2-1.x86_64/src/qtxmlpatterns-opensource-src-5.9.2/examples/xmlpatterns/filetree/queries/listCPPFiles.xq
  0x0,0x0,0x1,0xc6,
  0x64,
  0x65,0x63,0x6c,0x61,0x72,0x65,0x20,0x76,0x61,0x72,0x69,0x61,0x62,0x6c,0x65,0x20,
  0x24,0x77,0x68,0x65,0x72,0x65,0x20,0x61,0x73,0x20,0x78,0x73,0x3a,0x73,0x74,0x72,
  0x69,0x6e,0x67,0x20,0x3a,0x3d,0x20,0x73,0x74,0x72,0x69,0x6e,0x67,0x28,0x24,0x66,
  0x69,0x6c,0x65,0x54,0x72,0x65,0x65,0x2f,0x40,0x66,0x69,0x6c,0x65,0x50,0x61,0x74,
  0x68,0x29,0x3b,0xa,0x3c,0x68,0x74,0x6d,0x6c,0x3e,0xa,0x20,0x20,0x3c,0x68,0x65,
  0x61,0x64,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x74,0x69,0x74,0x6c,0x65,0x3e,0x41,
  0x6c,0x6c,0x20,0x63,0x70,0x70,0x20,0x66,0x69,0x6c,0x65,0x73,0x20,0x69,0x6e,0x3a,
  0x20,0x7b,0x24,0x77,0x68,0x65,0x72,0x65,0x7d,0x3c,0x2f,0x74,0x69,0x74,0x6c,0x65,
  0x3e,0xa,0x20,0x20,0x3c,0x2f,0x68,0x65,0x61,0x64,0x3e,0xa,0x20,0x20,0x3c,0x62,
  0x6f,0x64,0x79,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x70,0x3e,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x63,0x70,0x70,0x2d,0x66,0x69,0x6c,0x65,0x73,0x20,0x66,0x6f,0x75,
  0x6e,0x64,0x20,0x69,0x6e,0x20,0x7b,0x24,0x77,0x68,0x65,0x72,0x65,0x7d,0x20,0x73,
  0x6f,0x72,0x74,0x65,0x64,0x20,0x62,0x79,0x20,0x73,0x69,0x7a,0x65,0x3a,0xa,0x20,
  0x20,0x20,0x20,0x3c,0x2f,0x70,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x75,0x6c,0x3e,
  0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x66,0x6f,0x72,0x20,0x24,0x66,0x69,
  0x6c,0x65,0x20,0x69,0x6e,0x20,0x24,0x66,0x69,0x6c,0x65,0x54,0x72,0x65,0x65,0x2f,
  0x2f,0x66,0x69,0x6c,0x65,0x5b,0x40,0x73,0x75,0x66,0x66,0x69,0x78,0x20,0x3d,0x20,
  0x22,0x63,0x70,0x70,0x22,0x5d,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x6f,0x72,0x64,
  0x65,0x72,0x20,0x62,0x79,0x20,0x78,0x73,0x3a,0x69,0x6e,0x74,0x65,0x67,0x65,0x72,
  0x28,0x24,0x66,0x69,0x6c,0x65,0x2f,0x40,0x73,0x69,0x7a,0x65,0x29,0xa,0x20,0x20,
  0x20,0x20,0x20,0x20,0x72,0x65,0x74,0x75,0x72,0x6e,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x3c,0x6c,0x69,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x7b,0x73,0x74,0x72,0x69,0x6e,0x67,0x28,0x24,0x66,0x69,0x6c,0x65,0x2f,
  0x40,0x66,0x69,0x6c,0x65,0x4e,0x61,0x6d,0x65,0x29,0x7d,0x2c,0x20,0x73,0x69,0x7a,
  0x65,0x3a,0x20,0x7b,0x73,0x74,0x72,0x69,0x6e,0x67,0x28,0x24,0x66,0x69,0x6c,0x65,
  0x2f,0x40,0x73,0x69,0x7a,0x65,0x29,0x7d,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x3c,0x2f,0x6c,0x69,0x3e,0xa,0x20,0x20,0x20,0x20,0x7d,0x20,0x3c,0x2f,0x75,
  0x6c,0x3e,0xa,0x20,0x20,0x3c,0x2f,0x62,0x6f,0x64,0x79,0x3e,0xa,0x3c,0x2f,0x68,
  0x74,0x6d,0x6c,0x3e,0xa,
    // /usr/src/ports/qt5-xmlpatterns/qt5-xmlpatterns-5.9.2-1.x86_64/src/qtxmlpatterns-opensource-src-5.9.2/examples/xmlpatterns/filetree/queries/wholeTree.xq
  0x0,0x0,0x0,0xa,
  0x24,
  0x66,0x69,0x6c,0x65,0x54,0x72,0x65,0x65,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // queries
  0x0,0x7,
  0x8,0xbc,0x8f,0x23,
  0x0,0x71,
  0x0,0x75,0x0,0x65,0x0,0x72,0x0,0x69,0x0,0x65,0x0,0x73,
    // listCPPFiles.xq
  0x0,0xf,
  0xd,0x3d,0x40,0x51,
  0x0,0x6c,
  0x0,0x69,0x0,0x73,0x0,0x74,0x0,0x43,0x0,0x50,0x0,0x50,0x0,0x46,0x0,0x69,0x0,0x6c,0x0,0x65,0x0,0x73,0x0,0x2e,0x0,0x78,0x0,0x71,
    // wholeTree.xq
  0x0,0xc,
  0x4,0x35,0xc0,0xb1,
  0x0,0x77,
  0x0,0x68,0x0,0x6f,0x0,0x6c,0x0,0x65,0x0,0x54,0x0,0x72,0x0,0x65,0x0,0x65,0x0,0x2e,0x0,0x78,0x0,0x71,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/queries
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/queries/wholeTree.xq
  0x0,0x0,0x0,0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x1,0xca,
0x0,0x0,0x1,0x5e,0xb8,0xe7,0xd2,0x50,
  // :/queries/listCPPFiles.xq
  0x0,0x0,0x0,0x14,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5e,0xb8,0xe7,0xd2,0x50,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_queries)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_queries)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_queries)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_queries)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_queries)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_queries)(); }
   } dummy;
}

==> qt5-xmlpatterns-debuginfo-5.9.3-1.tar.xz: usr/src/debug/qt5-xmlpatterns-5.9.3-1/examples/xmlpatterns/filetree/.rcc/qrc_queries.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-xmlpatterns/qt5-xmlpatterns-5.9.3-1.i686/src/qtxmlpatterns-opensource-src-5.9.3/examples/xmlpatterns/filetree/queries/listCPPFiles.xq
  0x0,0x0,0x1,0xc6,
  0x64,
  0x65,0x63,0x6c,0x61,0x72,0x65,0x20,0x76,0x61,0x72,0x69,0x61,0x62,0x6c,0x65,0x20,
  0x24,0x77,0x68,0x65,0x72,0x65,0x20,0x61,0x73,0x20,0x78,0x73,0x3a,0x73,0x74,0x72,
  0x69,0x6e,0x67,0x20,0x3a,0x3d,0x20,0x73,0x74,0x72,0x69,0x6e,0x67,0x28,0x24,0x66,
  0x69,0x6c,0x65,0x54,0x72,0x65,0x65,0x2f,0x40,0x66,0x69,0x6c,0x65,0x50,0x61,0x74,
  0x68,0x29,0x3b,0xa,0x3c,0x68,0x74,0x6d,0x6c,0x3e,0xa,0x20,0x20,0x3c,0x68,0x65,
  0x61,0x64,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x74,0x69,0x74,0x6c,0x65,0x3e,0x41,
  0x6c,0x6c,0x20,0x63,0x70,0x70,0x20,0x66,0x69,0x6c,0x65,0x73,0x20,0x69,0x6e,0x3a,
  0x20,0x7b,0x24,0x77,0x68,0x65,0x72,0x65,0x7d,0x3c,0x2f,0x74,0x69,0x74,0x6c,0x65,
  0x3e,0xa,0x20,0x20,0x3c,0x2f,0x68,0x65,0x61,0x64,0x3e,0xa,0x20,0x20,0x3c,0x62,
  0x6f,0x64,0x79,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x70,0x3e,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x63,0x70,0x70,0x2d,0x66,0x69,0x6c,0x65,0x73,0x20,0x66,0x6f,0x75,
  0x6e,0x64,0x20,0x69,0x6e,0x20,0x7b,0x24,0x77,0x68,0x65,0x72,0x65,0x7d,0x20,0x73,
  0x6f,0x72,0x74,0x65,0x64,0x20,0x62,0x79,0x20,0x73,0x69,0x7a,0x65,0x3a,0xa,0x20,
  0x20,0x20,0x20,0x3c,0x2f,0x70,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x75,0x6c,0x3e,
  0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x66,0x6f,0x72,0x20,0x24,0x66,0x69,
  0x6c,0x65,0x20,0x69,0x6e,0x20,0x24,0x66,0x69,0x6c,0x65,0x54,0x72,0x65,0x65,0x2f,
  0x2f,0x66,0x69,0x6c,0x65,0x5b,0x40,0x73,0x75,0x66,0x66,0x69,0x78,0x20,0x3d,0x20,
  0x22,0x63,0x70,0x70,0x22,0x5d,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x6f,0x72,0x64,
  0x65,0x72,0x20,0x62,0x79,0x20,0x78,0x73,0x3a,0x69,0x6e,0x74,0x65,0x67,0x65,0x72,
  0x28,0x24,0x66,0x69,0x6c,0x65,0x2f,0x40,0x73,0x69,0x7a,0x65,0x29,0xa,0x20,0x20,
  0x20,0x20,0x20,0x20,0x72,0x65,0x74,0x75,0x72,0x6e,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x3c,0x6c,0x69,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x7b,0x73,0x74,0x72,0x69,0x6e,0x67,0x28,0x24,0x66,0x69,0x6c,0x65,0x2f,
  0x40,0x66,0x69,0x6c,0x65,0x4e,0x61,0x6d,0x65,0x29,0x7d,0x2c,0x20,0x73,0x69,0x7a,
  0x65,0x3a,0x20,0x7b,0x73,0x74,0x72,0x69,0x6e,0x67,0x28,0x24,0x66,0x69,0x6c,0x65,
  0x2f,0x40,0x73,0x69,0x7a,0x65,0x29,0x7d,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x3c,0x2f,0x6c,0x69,0x3e,0xa,0x20,0x20,0x20,0x20,0x7d,0x20,0x3c,0x2f,0x75,
  0x6c,0x3e,0xa,0x20,0x20,0x3c,0x2f,0x62,0x6f,0x64,0x79,0x3e,0xa,0x3c,0x2f,0x68,
  0x74,0x6d,0x6c,0x3e,0xa,
    // /usr/src/ports/qt5-xmlpatterns/qt5-xmlpatterns-5.9.3-1.i686/src/qtxmlpatterns-opensource-src-5.9.3/examples/xmlpatterns/filetree/queries/wholeTree.xq
  0x0,0x0,0x0,0xa,
  0x24,
  0x66,0x69,0x6c,0x65,0x54,0x72,0x65,0x65,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // queries
  0x0,0x7,
  0x8,0xbc,0x8f,0x23,
  0x0,0x71,
  0x0,0x75,0x0,0x65,0x0,0x72,0x0,0x69,0x0,0x65,0x0,0x73,
    // listCPPFiles.xq
  0x0,0xf,
  0xd,0x3d,0x40,0x51,
  0x0,0x6c,
  0x0,0x69,0x0,0x73,0x0,0x74,0x0,0x43,0x0,0x50,0x0,0x50,0x0,0x46,0x0,0x69,0x0,0x6c,0x0,0x65,0x0,0x73,0x0,0x2e,0x0,0x78,0x0,0x71,
    // wholeTree.xq
  0x0,0xc,
  0x4,0x35,0xc0,0xb1,
  0x0,0x77,
  0x0,0x68,0x0,0x6f,0x0,0x6c,0x0,0x65,0x0,0x54,0x0,0x72,0x0,0x65,0x0,0x65,0x0,0x2e,0x0,0x78,0x0,0x71,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/queries
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/queries/wholeTree.xq
  0x0,0x0,0x0,0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x1,0xca,
0x0,0x0,0x1,0x5f,0x9a,0xa1,0x58,0x10,
  // :/queries/listCPPFiles.xq
  0x0,0x0,0x0,0x14,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x9a,0xa1,0x58,0x10,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_queries)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_queries)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_queries)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_queries)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_queries)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_queries)(); }
   } dummy;
}
